@@ -5,8 +5,6 @@ sapply(studyPathS, function(studyPath){
   
 opts <- setSimulationPath(studyPath, 1)
 
-if(!isH5Opts(opts))
-{
 describe("readOptimCriteria", {
   it("returns an antaresDataTable", {
     optimCrit <- readOptimCriteria(opts)
@@ -16,5 +14,4 @@ describe("readOptimCriteria", {
     expect_equal(attr(optimCrit, "timeStep"), "weekly")
   })
 })
-}
 })
